@@ -37,9 +37,6 @@ private:
     QLineEdit *location_lat;
     QLineEdit *location_lon;
     QLineEdit *location_acc;
-
-    QFormLayout *do_login();
-    QFormLayout *do_location();
 };
 
 #endif // LATITUDE_H
